@@ -55,7 +55,10 @@ def main():
     pathconfigfile = os.path.realpath(__file__).replace('fdogFAS.py', 'pathconfig.txt')
     with open(pathconfigfile) as f:
         toolpath = f.readline().strip()
-    features = featuretypes(toolpath + '/' + 'annoTools.txt')
+    if args.featuretypes:
+        features = featuretypes(args.featuretypes)
+    else:
+        features = featuretypes(toolpath + '/' + 'annoTools.txt')
     if args.no_lin:
         features = ([], features[1] + features[0])
     print('calculating FAS scores for ' + outname + '...')
@@ -141,10 +144,16 @@ def create_jobdict(joblist):  # check jobdict generation
 
 
 def manage_jobpool(jobdict, seed_names, seed_spec, weight_dir, tmp_path, cores, features, bidirectional, fasta):
+    missing = []
+    for spec in jobdict:
+        if not os.path.exists(weight_dir + "/" + spec + ".json"):
+            missing.append(spec)
     try:
         tmp_data = read_json(weight_dir + "/" + seed_spec + ".json")
     except FileNotFoundError:
-        raise Exception('Taxon: "' + seed_spec + '" is missing in the weight_dir')
+        missing.append(seed_spec)
+    if missing:
+        raise Exception('The following taxa are missing in the weight_dir:\n' + '\n'.join(missing))
     seed_weight = w_weight_correction("loge", tmp_data["count"])
     seed_proteome = tmp_data["feature"]
     missing = []
@@ -294,7 +303,7 @@ def write_phyloprofile(results, out_path, outname, groupdict):
 
 
 def get_options():
-    version = '1.11.2'
+    version = '1.11.5'
     parser = argparse.ArgumentParser(description='You are running FAS version ' + str(version) + '.',
                                      epilog="For more information on certain options, please refer to the wiki pages "
                                             "on github: https://github.com/BIONF/FAS/wiki")
@@ -320,7 +329,10 @@ def get_options():
     optional.add_argument("--cores", action="store", type=int, default=1,
                           help="number of cores used for parallel calculation")
     optional.add_argument("--no_lin", action='store_true',
-                          help="deactivate linearization for pfam/smart")
+                          help="deactivate linearization (for pfam/smart)")
+    optional.add_argument("-d, --featuretypes", type=str, default=None,
+                          help="inputfile that contains the tools/databases used for comparison. Please look at the "
+                               "FAS wiki pages for templates of the the featuretypes input file")
     arguments = parser.parse_args()
     return arguments
 
